@@ -11,11 +11,11 @@ URL::Normalize - Normalize/optimize URLs.
 
 =head1 VERSION
 
-Version 0.30
+Version 0.31
 
 =cut
 
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 
 =head1 SYNOPSIS
 
@@ -66,6 +66,8 @@ methods:
 
 =back
 
+You could think of this module as a URL-specific L<Bloom::Filter> helper.
+
 =head1 CONSTRUCTORS
 
 =head2 new( $url )
@@ -299,11 +301,15 @@ The default regular expressions for matching a directory index are:
 
 =over 4
 
-    /default\.aspx?
-    /index\.cgi'
-    /index\.php\d?
-    /index\.pl,
-    /index\.s?html?
+=item * C</default\.aspx?>
+
+=item * C</index\.cgi>
+
+=item * C</index\.php\d?>
+
+=item * C</index\.pl>
+
+=item * C</index\.s?html?>
 
 =back
 
@@ -537,9 +543,11 @@ fragments for logic, for example:
 
 =over 4
 
-    http://www.example.com/players#all
-    http://www.example.com/players#banned
-    http://www.example.com/players#top
+=item * C<http://www.example.com/players#all>
+
+=item * C<http://www.example.com/players#banned>
+
+=item * C<http://www.example.com/players#top>
 
 =back
 
@@ -566,8 +574,9 @@ output in response to what the fragment is, for example:
 
 =over 4
 
-    http://www.example.com/users#list
-    http://www.example.com/users#edit
+=item * C<http://www.example.com/users#list>
+
+=item * C<http://www.example.com/users#edit>
 
 =back
 
@@ -636,10 +645,13 @@ Default social query parameters are:
 
 =over 4
 
-    ncid
-    utm_campaign
-    utm_medium
-    utm_source
+=item * C<ncid>
+
+=item * C<utm_campaign>
+
+=item * C<utm_medium>
+
+=item * C<utm_source>
 
 =back
 
